@@ -154,8 +154,7 @@ class TestCanCreateEmptyDataFs(unittest.TestCase):
         self.server.run(self.empty_fs, '--rw')
         browser = Browser(self.server.url)
         self.assertTrue('zodbbrowser' in browser.contents)
-        self.assertTrue('zope.app.folder.folder.Folder' in browser.contents
-                        or 'zope.site.folder.Folder' in browser.contents)
+        self.assertTrue('persistent.mapping.PersistentMapping' in browser.contents)
 
     def test_cannot_start_in_read_only_mode(self):
         self.assertRaises(ReadOnlyError, self.server.run, self.empty_fs)
@@ -287,9 +286,9 @@ def test_suite():
     suite = unittest.defaultTestLoader.loadTestsFromModule(this)
     checker = RENormalizing([
         (re.compile(r'object at 0x[0-9a-fA-F]+'), 'object at 0xXXXXXXX'),
-        (re.compile(r'\btid[0-9]+'), 'tidXXXXXXXXXXXXXXXXXX'),
-        (re.compile(r'\btid=[0-9]+'), 'tid=XXXXXXXXXXXXXXXXXX'),
-        (re.compile(r'\boid=[0-9]+'), 'oid=XX'),
+        (re.compile(r'\btid[0-9xA-Fa-f]+'), 'tidXXXXXXXXXXXXXXXXXX'),
+        (re.compile(r'\btid=[0-9xA-Fa-f]+'), 'tid=XXXXXXXXXXXXXXXXXX'),
+        (re.compile(r'\boid=[0-9xA-Fa-f]+'), 'oid=XX'),
         (re.compile(r'\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d[.]\d\d\d\d\d\d'),
             'YYYY-MM-DD HH:MM:SS.SSSSSS'),
         (re.compile(r'\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d'),
