@@ -1,12 +1,14 @@
 import inspect
 
 from ZODB.utils import tid_repr
+from ZODB.interfaces import IConnection
 from persistent import Persistent
 from zope.proxy import removeAllProxies
 from zope.interface import implements
 from zope.component import adapts
 
-from zodbbrowser.interfaces import IObjectHistory
+from zodbbrowser.interfaces import IObjectHistory, IDatabaseHistory
+from zodbbrowser import cache
 
 
 class ZodbObjectHistory(object):
@@ -80,6 +82,10 @@ class ZodbObjectHistory(object):
                 '%r did not exist in or before transaction %r' %
                 (self._obj, tid_repr(tid)))
 
+    def loadStatePickle(self, tid=None):
+        return self._connection._storage.loadSerial(self._obj._p_oid,
+                                                    self.lastChange(tid))
+
     def loadState(self, tid=None):
         return self._connection.oldstate(self._obj, self.lastChange(tid))
 
@@ -89,3 +95,30 @@ class ZodbObjectHistory(object):
             self._obj.__setstate__(state)
             self._obj._p_changed = True
 
+
+class ZodbHistory(object):
+
+    adapts(IConnection)
+    implements(IDatabaseHistory)
+
+    def __init__(self, connection):
+        self._connection = connection
+        self._storage = connection._storage
+        self._tids = cache.getStorageTids(self._storage)
+
+    @property
+    def tids(self):
+        return tuple(self._tids) # readonlify
+
+    def __len__(self):
+        return len(self._tids)
+
+    def __iter__(self):
+        return self._storage.iterator()
+
+    def __getslice__(self, start, stop):
+        tids = self._tids[start:stop]
+        if not tids:
+            return []
+        return self._storage.iterator(tids[0], tids[-1])
+
